pub struct AccessibilityTree { /* private fields */ }Implementations
Sourceimpl AccessibilityTree
impl AccessibilityTree
Sourcepub fn from_retained(
tree: &RetainedUiTree,
geometry: &GeometryRegistry,
) -> Result<Self, AccessibilityError>
pub fn from_retained( tree: &RetainedUiTree, geometry: &GeometryRegistry, ) -> Result<Self, AccessibilityError>
Build a stable semantic tree from retained identity and committed geometry.
Nodes without semantics are flattened; their semantic descendants attach to the nearest semantic ancestor.
Errors
Returns AccessibilityError::DuplicateSemanticId for ambiguous IDs.
Sourcepub fn from_presented(
tree: &RetainedUiTree,
geometry: &GeometryRegistry,
) -> Result<Self, AccessibilityError>
pub fn from_presented( tree: &RetainedUiTree, geometry: &GeometryRegistry, ) -> Result<Self, AccessibilityError>
Build the semantic tree from nodes that participated in the latest committed GPUI presentation frame.
Errors
Returns AccessibilityError::DuplicateSemanticId for ambiguous IDs
among currently presented nodes.
pub fn root_ids(&self) -> &[NodeId]
pub fn node(&self, id: NodeId) -> Option<&AccessibilityNode>
pub fn nodes(&self) -> impl ExactSizeIterator<Item = &AccessibilityNode>
pub fn find_by_semantic_id(&self, id: &str) -> Option<&AccessibilityNode>
pub fn find_by_role_and_name<'a>( &'a self, role: &'a str, name: &'a str, ) -> impl Iterator<Item = &'a AccessibilityNode> + 'a
pub fn find_by_test_id<'a>( &'a self, id: &'a str, ) -> impl Iterator<Item = &'a AccessibilityNode> + 'a