pub enum ExecutionOperation {
Compile,
Render,
ComponentReuse(usize),
VirtualCollection(String),
Lifecycle(String),
Callback(String),
}Variants
Compile
Render
ComponentReuse(usize)
A formal-component subtree returned without executing its Rhai render. The payload is the number of retained formal component instances in the reused subtree, including its root.
VirtualCollection(String)
Lifecycle(String)
Callback(String)