pub struct EventRouter { /* private fields */ }Implementations
Sourceimpl EventRouter
impl EventRouter
pub fn new() -> Self
pub fn bind( &mut self, target: ComponentInstancePath, event: impl Into<String>, callback: ScriptCallback, )
pub fn bind_phase( &mut self, target: ComponentInstancePath, event: impl Into<String>, phase: EventPhase, handler: impl Into<UiEventHandler>, )
pub fn unbind_component(&mut self, target: &ComponentInstancePath)
Sourcepub fn dispatch<E>(
&self,
target: &ComponentInstancePath,
event: &UiEvent,
invoke: impl FnMut(&ComponentInstancePath, &UiEventHandler, &UiEvent) -> Result<EventResponse, E>,
) -> Result<EventDispatchReport, E>
pub fn dispatch<E>( &self, target: &ComponentInstancePath, event: &UiEvent, invoke: impl FnMut(&ComponentInstancePath, &UiEventHandler, &UiEvent) -> Result<EventResponse, E>, ) -> Result<EventDispatchReport, E>
Bubble a normalized event from its target toward the root.
Errors
Propagates errors returned by the callback invoker and stops dispatch.