pub struct NativeCollectionRegistry { /* private fields */ }Implementations
Sourceimpl NativeCollectionRegistry
impl NativeCollectionRegistry
pub fn new() -> Self
Sourcepub fn register(
&mut self,
name: impl Into<String>,
collection: NativeCollection,
) -> Result<(), NativeCollectionError>
pub fn register( &mut self, name: impl Into<String>, collection: NativeCollection, ) -> Result<(), NativeCollectionError>
Register one application-owned collection before initial render.
Errors
Returns an error for an unsafe or duplicate name.
Sourcepub fn replace(
&mut self,
name: &str,
collection: NativeCollection,
) -> Result<BTreeSet<ComponentInstancePath>, NativeCollectionError>
pub fn replace( &mut self, name: &str, collection: NativeCollection, ) -> Result<BTreeSet<ComponentInstancePath>, NativeCollectionError>
Replace an existing collection and return its exact subscribed readers.
Errors
Returns an error when the collection is unknown.