pub struct ResponsiveRuntime { /* private fields */ }Implementations
Sourceimpl ResponsiveRuntime
impl ResponsiveRuntime
pub fn new(breakpoints: ViewportBreakpoints) -> Self
Sourcepub fn update_window(
&mut self,
window: &str,
width: f64,
) -> Result<bool, ResponsiveError>
pub fn update_window( &mut self, window: &str, width: f64, ) -> Result<bool, ResponsiveError>
Update one window and report whether its discrete class changed.
Errors
Returns invalid-width errors.
Sourcepub fn would_update_window(
&self,
window: &str,
width: f64,
) -> Result<bool, ResponsiveError>
pub fn would_update_window( &self, window: &str, width: f64, ) -> Result<bool, ResponsiveError>
Check a width without mutating the committed viewport class.
Errors
Returns ResponsiveError::InvalidWidth for invalid geometry.
pub fn class(&self, window: &str) -> ViewportClass
pub fn remove_window(&mut self, window: &str) -> bool
pub const fn breakpoints(&self) -> ViewportBreakpoints