pub struct RestrictedModuleResolver { /* private fields */ }Expand description
A resolver that can only load explicitly registered, logical module IDs.
It never reads the filesystem and rejects path traversal, absolute paths, platform path syntax, and cyclic imports.
Implementations
Sourceimpl RestrictedModuleResolver
impl RestrictedModuleResolver
pub fn new() -> Self
Sourcepub fn from_source(
source: &impl ScriptSource,
) -> Result<Self, ScriptSourceError>
pub fn from_source( source: &impl ScriptSource, ) -> Result<Self, ScriptSourceError>
Snapshot every module from a file or embedded script source.
Errors
Returns ScriptSourceError when any declared module cannot be loaded.
Sourcepub fn from_source_with_cache(
source: &impl ScriptSource,
cache: &ModuleCompileCache,
) -> Result<Self, ScriptSourceError>
pub fn from_source_with_cache( source: &impl ScriptSource, cache: &ModuleCompileCache, ) -> Result<Self, ScriptSourceError>
Snapshot source while reusing transactionally compiled module ASTs.
Errors
Returns source errors for declared modules that cannot load.
Sourcepub fn insert(
&mut self,
id: impl Into<String>,
source: impl Into<String>,
) -> Result<(), ModuleIdError>
pub fn insert( &mut self, id: impl Into<String>, source: impl Into<String>, ) -> Result<(), ModuleIdError>
Register source under a validated logical module identifier.
Errors
Returns ModuleIdError when id violates the resolver’s path rules.
pub fn contains(&self, id: &ModuleId) -> bool