pub struct RenderStateTransaction { /* private fields */ }Implementations
Sourceimpl RenderStateTransaction
impl RenderStateTransaction
Sourcepub fn retain_existing(&mut self, path: &ComponentInstancePath) -> bool
pub fn retain_existing(&mut self, path: &ComponentInstancePath) -> bool
Retain a previously mounted instance without changing its schema.
Sourcepub fn mount(
&mut self,
path: ComponentInstancePath,
schema: &ComponentStateSchema,
) -> Result<StateReconcileReport, StateError>
pub fn mount( &mut self, path: ComponentInstancePath, schema: &ComponentStateSchema, ) -> Result<StateReconcileReport, StateError>
Mount or reconcile an instance inside this prospective render.
Errors
Returns StateError::InvalidDefault if a programmatically constructed
schema contains an invalid default.