pub struct QueuedWindowCommand { /* private fields */ }Expand description
A command and the qualifications captured when it was enqueued.
A native pump must not replace this origin with its own authority. Rust request methods without a source explicitly use trusted Host origin.
Implementations
Sourceimpl QueuedWindowCommand
impl QueuedWindowCommand
pub const fn command(&self) -> &WindowCommand