pub struct WindowCommandRegistry { /* private fields */ }Implementations
Sourceimpl WindowCommandRegistry
impl WindowCommandRegistry
pub fn new() -> Self
Sourcepub fn register_open(
&mut self,
id: impl Into<String>,
) -> Result<(), WindowCommandError>
pub fn register_open( &mut self, id: impl Into<String>, ) -> Result<(), WindowCommandError>
Sourcepub fn register_open_with_policy(
&mut self,
id: impl Into<String>,
policy: WindowCommandPolicy,
) -> Result<(), WindowCommandError>
pub fn register_open_with_policy( &mut self, id: impl Into<String>, policy: WindowCommandPolicy, ) -> Result<(), WindowCommandError>
Register an existing host window with an explicit script command policy.
Errors
Returns duplicate, limit, or invalid-ID errors.
Sourcepub fn register_open_for_view(
&mut self,
id: impl Into<String>,
policy: WindowCommandPolicy,
view_id: impl Into<String>,
) -> Result<(), WindowCommandError>
pub fn register_open_for_view( &mut self, id: impl Into<String>, policy: WindowCommandPolicy, view_id: impl Into<String>, ) -> Result<(), WindowCommandError>
Register an existing host window and its owning mounted view.
Errors
Returns duplicate, limit, or invalid-ID errors.
Sourcepub fn request_open(
&mut self,
spec: ScriptWindowSpec,
) -> Result<(), WindowCommandError>
pub fn request_open( &mut self, spec: ScriptWindowSpec, ) -> Result<(), WindowCommandError>
Validate and queue creation of another instance of the script entry.
Errors
Returns duplicate, limit, queue, or spec validation errors. This Rust
entry explicitly uses trusted Host origin; scripts use request_open_from.
Sourcepub fn mark_open(&mut self, id: &str) -> Result<(), WindowCommandError>
pub fn mark_open(&mut self, id: &str) -> Result<(), WindowCommandError>
Mark successful native creation of a queued window.
Errors
Returns unknown-window errors or an invalid transition.
pub fn fail_open(&mut self, id: &str)
Sourcepub fn request_focus(&mut self, id: &str) -> Result<(), WindowCommandError>
pub fn request_focus(&mut self, id: &str) -> Result<(), WindowCommandError>
Queue native focus with trusted Rust Host origin. A pending Open in the same queue is a valid target and retains the same reservation identity.
Errors
Returns unknown-window or queue-limit errors.
Sourcepub fn request_focus_from(
&mut self,
source: &str,
id: &str,
) -> Result<(), WindowCommandError>
pub fn request_focus_from( &mut self, source: &str, id: &str, ) -> Result<(), WindowCommandError>
Queue focus after verifying that the source view owns window commands.
Errors
Returns disabled-policy, unknown-window, or queue errors.
Sourcepub fn request_close(&mut self, id: &str) -> Result<(), WindowCommandError>
pub fn request_close(&mut self, id: &str) -> Result<(), WindowCommandError>
Queue forced close with trusted Rust Host origin.
Errors
Returns unknown-window or queue-limit errors.
Sourcepub fn request_close_from(
&mut self,
source: &str,
id: &str,
) -> Result<(), WindowCommandError>
pub fn request_close_from( &mut self, source: &str, id: &str, ) -> Result<(), WindowCommandError>
Queue close after verifying that the source view owns window commands.
Errors
Returns disabled-policy, unknown-window, or queue errors.
Sourcepub fn request_open_from(
&mut self,
source: &str,
spec: ScriptWindowSpec,
) -> Result<(), WindowCommandError>
pub fn request_open_from( &mut self, source: &str, spec: ScriptWindowSpec, ) -> Result<(), WindowCommandError>
Queue open after verifying that the source view owns window commands.
Errors
Returns disabled-policy, validation, duplicate, limit, or queue errors.
Sourcepub fn set_close_handler(
&mut self,
id: &str,
handler: Option<ScriptCallback>,
) -> Result<(), WindowCommandError>
pub fn set_close_handler( &mut self, id: &str, handler: Option<ScriptCallback>, ) -> Result<(), WindowCommandError>
Install or clear the current generation’s close-request callback.
Errors
Returns WindowCommandError::Unknown for an absent window.
pub fn close_handler(&self, id: &str) -> Option<ScriptCallback>
pub fn drain_commands(&mut self) -> Vec<QueuedWindowCommand>
pub fn contains(&self, id: &str) -> bool
pub fn open_ids(&self) -> Vec<String>
pub fn remove(&mut self, id: &str) -> bool